@@ -94,12 +94,10 @@ struct _YelpDocumentPriv {
     GError *idle_error;
 };
 
-G_DEFINE_TYPE (YelpDocument, yelp_document, G_TYPE_OBJECT);
+G_DEFINE_TYPE (YelpDocument, yelp_document, G_TYPE_OBJECT)
 
 #define GET_PRIV(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_DOCUMENT, YelpDocumentPriv))
 
-static void           yelp_document_class_init  (YelpDocumentClass    *klass);
-static void           yelp_document_init        (YelpDocument         *document);
 static void           yelp_document_dispose     (GObject              *object);
 static void           yelp_document_finalize    (GObject              *object);
 static void           document_get_property     (GObject              *object,
@@ -152,7 +150,7 @@ static const gchar *  str_ref                   (const gchar          *str);
 static void           str_unref                 (const gchar          *str);
 
 static GMutex str_mutex;
-GHashTable  *str_refs  = NULL;
+static GHashTable  *str_refs  = NULL;
 
 /******************************************************************************/
 
@@ -160,6 +158,7 @@ YelpDocument *
 yelp_document_get_for_uri (YelpUri *uri)
 {
     static GHashTable *documents = NULL;
+    YelpUriDocumentType doctype;
     gchar *docuri = NULL;
     gchar *page_id, *tmp;
     YelpDocument *document = NULL;
@@ -170,10 +169,11 @@ yelp_document_get_for_uri (YelpUri *uri)
 
     g_return_val_if_fail (yelp_uri_is_resolved (uri), NULL);
 
-    switch (yelp_uri_get_document_type (uri)) {
-    case YELP_URI_DOCUMENT_TYPE_TEXT:
-    case YELP_URI_DOCUMENT_TYPE_HTML:
-    case YELP_URI_DOCUMENT_TYPE_XHTML:
+    doctype = yelp_uri_get_document_type (uri);
+
+    if (doctype == YELP_URI_DOCUMENT_TYPE_TEXT ||
+        doctype == YELP_URI_DOCUMENT_TYPE_HTML ||
+        doctype == YELP_URI_DOCUMENT_TYPE_XHTML) {
         /* We use YelpSimpleDocument for these, which is a single-file
          * responder. But the document URI may be set to the directory
          * holding the file, to allow a directory of HTML files to act
@@ -185,16 +185,15 @@ yelp_document_get_for_uri (YelpUri *uri)
         g_free (docuri);
         g_free (page_id);
         docuri = tmp;
-        break;
-    case YELP_URI_DOCUMENT_TYPE_MAN:
+    }
+    else if (doctype == YELP_URI_DOCUMENT_TYPE_MAN) {
         /* The document URI for man pages is just man:, so we use the
          * full canonical URI to look these up.
          */
         docuri = yelp_uri_get_canonical_uri (uri);
-        break;
-    default:
+    }
+    else {
         docuri = yelp_uri_get_document_uri (uri);
-        break;
     }
 
     if (docuri == NULL)
@@ -231,6 +230,9 @@ yelp_document_get_for_uri (YelpUri *uri)
     case YELP_URI_DOCUMENT_TYPE_EXTERNAL:
     case YELP_URI_DOCUMENT_TYPE_ERROR:
         break;
+    case YELP_URI_DOCUMENT_TYPE_UNRESOLVED:
+    default:
+        g_assert_not_reached ();
     }
 
     if (document != NULL) {
@@ -1351,7 +1353,7 @@ request_idle_contents (Request *request)
     YelpDocument *document;
     YelpDocumentPriv *priv;
     YelpDocumentCallback callback = NULL;
-    gpointer user_data = user_data;
+    gpointer user_data;
 
     g_assert (request != NULL && YELP_IS_DOCUMENT (request->document));
 
@@ -1418,7 +1420,7 @@ request_idle_error (Request *request)
     YelpDocumentPriv *priv;
     YelpDocumentCallback callback = NULL;
     GError *error = NULL;
-    gpointer user_data = user_data;
+    gpointer user_data;
 
     g_assert (request != NULL && YELP_IS_DOCUMENT (request->document));
 
